==> atlassian_connect_host-0.3.1.tar.gz: test/host_service/host_service_registration_test.dart <==
library ac_dart.host_service.registration.test;

import 'package:atlassian_connect_host/src/host_service/host_service.dart';
import 'package:atlassian_connect_host/host_model.dart';
import 'package:atlassian_connect_host/host_event_model.dart';
import 'package:unittest/unittest.dart';
import 'package:unittest/mock.dart';
import 'package:atlassian_connect_host/host_registration_persistence.dart';
import 'dart:io';

class _MockAcHostRegistrationRepository extends Mock implements
    AcHostRegistrationRepository {
  noSuchMethod(i) => super.noSuchMethod(i);
}

// HostClientFactory is a typedef
class _MockHostClientFactory extends Mock {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockAcHostHttpClient extends Mock implements AcHostHttpClient {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpClientRequest extends Mock implements HttpClientRequest {
  noSuchMethod(i) => super.noSuchMethod(i);  
}

class _MockHttpHeaders extends Mock implements HttpHeaders {
  noSuchMethod(i) => super.noSuchMethod(i);  
}

class _MockHttpClientResponse extends Mock implements HttpClientResponse {
  noSuchMethod(i) => super.noSuchMethod(i);  
}


main() {
  const String addonKey = 'my-addon';
  final Uri addonBaseUri = Uri.parse('http://localhost:9999/foo');
  const String hostKey = 'jira:2345';
  const String publicKey = '93475ljsdrt93kwd';
  
  final AddonHost addonHost = new AddonHost(addonKey, addonBaseUri);
  
  final _hostRegistration = (new MutableAcHostRegistration()
      ..sharedSecret = "1234"
      ..hostDetails = (new MutableAcHostDetails()
          ..key = "$hostKey"
          ..baseUrl = Uri.parse('http://localhost:8080/blah')
          ..productType = ProductType.jira
          ..publicKey = "$publicKey")).toImmutable();

  final _installationEvent = new InstallationEvent(AcHostEventType.installed,
      _hostRegistration);

  _MockAcHostRegistrationRepository _registrationRepository;
  _MockHostClientFactory _hostClientFactory;
  _MockAcHostHttpClient _hostHttpClient;
  _MockHttpClientRequest _httpClientRequest;
  _MockHttpHeaders _httpHeaders;
  _MockHttpClientResponse _httpClientResponse;
  
  const String _goodRespXml = '''
    <resp>
      <key>$hostKey</key>
      <publicKey>$publicKey</publicKey>
    </resp>
    ''';


  group('[Registration]', () {
    AcHostService hostService;

    setUp(() {
      _registrationRepository = new _MockAcHostRegistrationRepository();
      _hostClientFactory = new _MockHostClientFactory();
      hostService = new AcHostService(_registrationRepository, addonHost, 
          (hostRego, addonHost) => _hostClientFactory.call(hostRego, addonHost));
      _hostHttpClient = new _MockAcHostHttpClient();
      _httpClientRequest = new _MockHttpClientRequest();
      _httpHeaders = new _MockHttpHeaders();
      _httpClientResponse = new _MockHttpClientResponse();
      
      _hostClientFactory.when(callsTo('call')).alwaysReturn(_hostHttpClient);
      _hostHttpClient.when(callsTo('get')).alwaysReturn(new Future.value(_httpClientRequest));
      _httpClientRequest.when(callsTo('get headers')).alwaysReturn(_httpHeaders);
      _httpClientRequest.when(callsTo('close')).alwaysReturn(new Future.value(_httpClientResponse));
      _httpClientResponse.when(callsTo('transform')).alwaysReturn(_httpClientResponse);
      _httpClientResponse.when(callsTo('fold')).alwaysReturn(new Future.value(_goodRespXml));
      _registrationRepository.when(callsTo('create')).alwaysReturn(_hostRegistration);
      
      // ouch ended up being a truck load of mocking!!!
    });

    //TODO: lots more test cases.

    test('persists registration', () {
      _registrationRepository.when(callsTo('findRegistrationByHostKey'))
          .alwaysReturn(new Future.value(const None()));
      
      final Future<AcHostRegistration> regoFuture = hostService.registerHost(_installationEvent);
      regoFuture.then((_) {
        _registrationRepository.calls('create', _hostRegistration).verify(
            happenedOnce);
      });
      expect(regoFuture, completes);
    });

    test('rejects registration if exsiting for key', () {
      _registrationRepository.when(callsTo('findRegistrationByHostKey'))
          .alwaysReturn(new Future.value(new Some(_hostRegistration)));
      
      final Future<AcHostRegistration> regoFuture = hostService.registerHost(_installationEvent);
      expect(regoFuture, throwsArgumentError);
    });
  });
  
  
  // TODO: unittest installAddonToHost
}

==> atlassian_connect_host-0.4.0.tar.gz: test/host_service/host_service_registration_test.dart <==
library ac_dart.host_service.registration.test;

import 'package:atlassian_connect_host/src/host_service/host_service.dart';
import 'package:atlassian_connect_host/host_model.dart';
import 'package:atlassian_connect_host/host_event_model.dart';
import 'package:unittest/unittest.dart';
import 'package:mock/mock.dart';
import 'package:atlassian_connect_host/host_registration_persistence.dart';
import 'dart:io';

class _MockAcHostRegistrationRepository extends Mock implements
    AcHostRegistrationRepository {
  noSuchMethod(i) => super.noSuchMethod(i);
}

// HostClientFactory is a typedef
class _MockHostClientFactory extends Mock {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockAcHostHttpClient extends Mock implements AcHostHttpClient {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpClientRequest extends Mock implements HttpClientRequest {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpHeaders extends Mock implements HttpHeaders {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpClientResponse extends Mock implements HttpClientResponse {
  noSuchMethod(i) => super.noSuchMethod(i);
}


main() {
  const String addonKey = 'my-addon';
  final Uri addonBaseUri = Uri.parse('http://localhost:9999/foo');
  const String hostKey = 'jira:2345';
  const String publicKey = '93475ljsdrt93kwd';

  final AddonHost addonHost = new AddonHost(addonKey, addonBaseUri);

  final _hostRegistration = (new AcHostRegistration.build(
      sharedSecret: "1234",
      hostDetails: (new AcHostDetails.build(
          key: "$hostKey",
          baseUrl: Uri.parse('http://localhost:8080/blah'),
          productType: ProductType.jira,
          publicKey: "$publicKey"))));

  final _installationEvent = new InstallationEvent(_hostRegistration);

  _MockAcHostRegistrationRepository _registrationRepository;
  _MockHostClientFactory _hostClientFactory;
  _MockAcHostHttpClient _hostHttpClient;
  _MockHttpClientRequest _httpClientRequest;
  _MockHttpHeaders _httpHeaders;
  _MockHttpClientResponse _httpClientResponse;

  const String _goodRespXml = '''
    <resp>
      <key>$hostKey</key>
      <publicKey>$publicKey</publicKey>
    </resp>
    ''';


  group('[Registration]', () {
    AcHostService hostService;

    setUp(() {
      _registrationRepository = new _MockAcHostRegistrationRepository();
      _hostClientFactory = new _MockHostClientFactory();
      hostService = new AcHostService(_registrationRepository, addonHost,
          (hostRego, addonHost) => _hostClientFactory.call(hostRego, addonHost));
      _hostHttpClient = new _MockAcHostHttpClient();
      _httpClientRequest = new _MockHttpClientRequest();
      _httpHeaders = new _MockHttpHeaders();
      _httpClientResponse = new _MockHttpClientResponse();

      _hostClientFactory.when(callsTo('call')).alwaysReturn(_hostHttpClient);
      _hostHttpClient.when(callsTo('get')).alwaysReturn(new Future.value(_httpClientRequest));
      _httpClientRequest.when(callsTo('get headers')).alwaysReturn(_httpHeaders);
      _httpClientRequest.when(callsTo('close')).alwaysReturn(new Future.value(_httpClientResponse));
      _httpClientResponse.when(callsTo('transform')).alwaysReturn(_httpClientResponse);
      _httpClientResponse.when(callsTo('fold')).alwaysReturn(new Future.value(_goodRespXml));
      _registrationRepository.when(callsTo('create')).alwaysReturn(_hostRegistration);

      // ouch ended up being a truck load of mocking!!!
    });

    //TODO: lots more test cases.

    test('persists registration', () {
      _registrationRepository.when(callsTo('findRegistrationByHostKey'))
          .alwaysReturn(new Future.value(const None()));

      final Future<AcHostRegistration> regoFuture = hostService.registerHost(_installationEvent);
      regoFuture.then((_) {
        _registrationRepository.calls('create', _hostRegistration).verify(
            happenedOnce);
      });
      expect(regoFuture, completes);
    });

    test('rejects registration if exsiting for key', () {
      _registrationRepository.when(callsTo('findRegistrationByHostKey'))
          .alwaysReturn(new Future.value(new Some(_hostRegistration)));

      final Future<AcHostRegistration> regoFuture = hostService.registerHost(_installationEvent);
      expect(regoFuture, throwsArgumentError);
    });
  });


  // TODO: unittest installAddonToHost
}
